% Copy all files in Matlab current directory and type "ecgrec" on
% Matlab command window: a simple and intuitive GUI will appear.
% 
% Click on "Select ECG sequence(s)" button to select one or more
% ECG sequences. ECG sequence is an ECG Matlab .mat file with 16 ECG
% channels.
% Now you have selected one or more ECG sequences you can:
% - Add selected sequences to database (an ID is required)
% - Perform ECG recognition (but in this case you must have already
%   inserted some ECG sequences to database).
% When you add one or more ECG sequences to database you have to
% specify an ID: ID is a progressive, non negative integer number that is
% associated to class. When you click on "ECG Recognition" button selected ECG
% sequences will be compared with ECG sequences present in database.
% For each unknown sequence the recognized ID will be returned.
%
% In order to create the .mat files with ECG channels:
%
%  1. Download and istall http://physionet.org/physiotools/matlab/wfdb-swig-matlab/wfdb-swig-matlab.jnlp
%     The WFDB Toolbox for MATLAB is a collection of applications for
%     reading, writing, manipulating, and plotting PhysioBank data, implemented as functions in MATLAB.
%  2. Download in Matlab current directory the three files associated to ECG
%     signals (.hea file, .dat file and .xyz file). For example download
%     these files:
%     http://www.physionet.org/physiobank/database/ptbdb/patient001/s0010_re.dat
%     http://www.physionet.org/physiobank/database/ptbdb/patient001/s0010_re.hea
%     http://www.physionet.org/physiobank/database/ptbdb/patient001/s0010_re.xyz
%  3. Read ECG channels with "rdsamp" command. 
%     Example: ECGSignal = rdsamp('s0010_re');
%     Now ECGSignal is a N-by-16 matrix with ECG channels along columns.
%  4. Save variable on disk. 
%     Example: save MyECGData ECGSignal
%     The previous command saves ECGSignal matrix in "MyECGData.mat" file on disk.
%  5. Now the .mat file can be read by ECG Recognition System using "Select ECG sequence(s)" button.
%
% NOTE: you can use the script createdb.m to convert all PTB ECG files into
% Matlab variables. In order to quickly download all files from the web you
% can use HTTrack Website Copier available at http://www.httrack.com/page/2/en/index.html
% 
% References:
% 
%  The PTB Diagnostic ECG Database
%  available at http://www.physionet.org/physiobank/database/ptbdb/
%
%  The WFDB Toolbox for MATLAB
%  available at http://physionet.org/physiotools/matlab/wfdb-swig-matlab/
% 
% FUNCTIONS
%
% Select ECG sequence:                           read the input ECG sequence
%
% Add selected ECG sequence to database:         the input ECG sequence is added to database and will be used for training
%
% Database Info:                                 show informations about the ECG files present in database.
%
% ECG Recognition:                               ECG recognition. The selected ECG sequence is loaded and compared with
%                                                sequences present in database
%
% Delete Database:                               remove database from the current directory
%
% Info:                                          show informations about this software
%
%
% Source code for ECG Recognition System:        how to obtain the complete source code
%
% Exit:                                          quit program
%
%
%
